# Change log

## 1.0.0

- Fix: Whiteless is only used on first run of a for loop ([#1][i1])
- Add Django 3.x support
- Add Python 3.8 and 3.9 support
- Drop Django 1.11 support
- Drop Python 2.7, 3.5 and 3.6 support

## 0.1.0 through 0.1.3

- First release
- Packaging fixes
- Metadata additions
- Documentation

[i1]: https://github.com/denizdogan/django-whiteless/issues/1
